pub enum ProgressStyle {
Number,
Percentage,
Empty,
}Variants
Number
A number that shows how many actions have been finished and how many actions there are. Example: 23/57
Percentage
A percentage of the completed work is shown. Example: 32%
Empty
No indication of progression is shown next to the progress bar.